# Copyright 2020 Akretion (http://www.akretion.com).
# @author: Sébastien BEAU <sebastien.beau@akretion.com>
# License LGPL-3.0 or later (http://www.gnu.org/licenses/lgpl).


{
    "name": "Test Helper",
    "summary": "Fake module for testing",
    "version": "0.0.0",
    "category": "Uncategorized",
    "website": "http://github.com/OCA/odoo-test-helper",
    "author": " Odoo Community Association (OCA)",
    "license": "LGPL-3",
    "depends": ["base"],
}
